@@ -1,13 +1,14 @@
+use hotg_rune_runtime::Output;
 use regex::Regex;
 use std::{path::PathBuf, str::FromStr};
 use anyhow::{Context, Error};
 use log;
-use hotg_rune_core::capabilities;
+use hotg_rune_core::{Shape, capabilities};
 use once_cell::sync::Lazy;
 use crate::run::{
     Accelerometer, Image, Raw, Sound, accelerometer::Samples,
     image::ImageSource, multi::SourceBackedCapability, new_capability_switcher,
-    resources, runecoral_inference, sound::AudioClip,
+    resources, sound::AudioClip,
 };
 use hotg_runicos_base_runtime::{BaseImage, CapabilityFactory, Random};
 
@@ -48,12 +49,6 @@ pub struct Run {
         help = "Seed the runtime's Random Number Generator"
     )]
     random: Option<u64>,
-    #[structopt(
-        long,
-        env,
-        help = "The librunecoral.so library to use for hardware acceleration"
-    )]
-    librunecoral: Option<PathBuf>,
     #[structopt(
         long,
         help = "Use the wasm3 WebAssembly engine instead of Wasmer"
@@ -116,20 +111,19 @@ impl Run {
         let mut img = BaseImage::with_defaults();
 
         self.register_capabilities(&mut img)?;
+        self.register_outputs(&mut img);
 
-        resources::load_from_custom_sections(&mut img, rune);
+        resources::load_from_custom_sections(&mut img, rune)?;
         resources::load_from_files(&mut img, &self.file_resources);
         resources::load_from_strings(&mut img, &self.string_resources);
 
-        runecoral_inference::override_model_handler(
-            &mut img,
-            self.librunecoral.as_deref(),
-        )
-        .context("Unable to register the librunecoral inference backend")?;
-
         Ok(img)
     }
 
+    fn register_outputs(&self, img: &mut BaseImage) {
+        img.register_output(hotg_rune_core::outputs::SERIAL, serial_output);
+    }
+
     /// Load the source files for each kind of capability and create a
     /// [`CapabilityFactory`] which will instantiate capabilities depending on
     /// the "source" index provided as a capability parameter.
@@ -241,3 +235,21 @@ impl FromStr for StringResource {
         })
     }
 }
+
+fn serial_output(_: Option<&[Shape<'_>]>) -> Result<Box<dyn Output>, Error> {
+    Ok(Box::new(Serial::default()))
+}
+
+#[derive(Debug, Clone, Copy, Default)]
+struct Serial;
+
+impl Output for Serial {
+    fn consume(&mut self, buffer: &[u8]) -> Result<(), Error> {
+        let json = std::str::from_utf8(buffer)
+            .context("Unable to parse the input as UTF-8")?;
+
+        println!("{}", json);
+
+        Ok(())
+    }
+}
