@@ -1,17 +1,18 @@
+//! The various unstable/internal flags you can use with Rune.
+//!
+//! # Note to Implementors
+//!
+//! To make sure people explicitly opt into unstable features and have a
+//! consistent experience, there are a couple requirements:
+//!
+//! - Set `global = true` so unstable flags can be placed anywhere on the
+//!   command-line
+//! - Set `requires = "enable_unstable"` so you can only use unstable features
+//!   after explicitly opting in.
+
 use std::path::PathBuf;
 use hotg_rune_compiler::FeatureFlags;
 
-/// The various unstable/internal flags you can use with Rune.
-///
-/// # Note to Implementors
-///
-/// To make sure people explicitly opt into unstable features and have a
-/// consistent experience, there are a couple requirements:
-///
-/// - Set `global = true` so unstable flags can be placed anywhere on the
-///   command-line
-/// - Set `requires = "enable_unstable"` so you can only use unstable features
-///   after explicitly opting in.
 #[derive(Debug, Clone, PartialEq, structopt::StructOpt)]
 pub struct Unstable {
     /// Enable unstable features.
@@ -21,6 +22,7 @@ pub struct Unstable {
     /// dependencies when hacking on Rune locally.
     #[structopt(
         long,
+        env,
         requires = "unstable",
         parse(from_os_str),
         global = true
